<?php

namespace App\Admin\Controllers;

use App\Admin\Repositories\UserMember;
use Dcat\Admin\Form;
use Dcat\Admin\Grid;
use Dcat\Admin\Show;
use Dcat\Admin\Http\Controllers\AdminController;

class UserMemberController extends AdminController
{
    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {
        return Grid::make(new UserMember(), function (Grid $grid) {
            $grid->column('id')->sortable();
            $grid->column('title');
            $grid->column('describe');
            $grid->column('updated_at')->sortable();
            $grid->disableFilter();
            $grid->disableCreateButton();
            $grid->disableViewButton();
            // 禁用删除按钮
            $grid->disableDeleteButton();
            $grid->disableBatchDelete();
            $grid->actions(function (Grid\Displayers\Actions $actions) {
                $actions->disableDelete();
                $actions->disableQuickEdit();
                $actions->disableView();
            });
        });
    }

    /**
     * Make a show builder.
     *
     * @param mixed $id
     *
     * @return Show
     */
    protected function detail($id)
    {
        return Show::make($id, new UserMember(), function (Show $show) {
            $show->field('id');
            $show->field('title');
            $show->field('describe');
            $show->field('money');
            $show->field('content');
            $show->field('created_at');
            $show->field('updated_at');
        });
    }

    /**
     * Make a form builder.
     *
     * @return Form
     */
    protected function form()
    {
        return Form::make(new UserMember(), function (Form $form) {
            $id = $form->getKey();
            $form->display('id')->width(4);
            $form->text('title')->width(4);
            $form->text('describe')->width(4);
            if($id == 2){
                $form->decimal('money')->width(4);
            }
            $form->editor('content')->width(4);
            $form->disableViewButton();
            $form->disableDeleteButton();
        });
    }
}
